from .circle import circle_area, circle_perimeter
from .triangle import triangle_area, triangle_perimeter
from .square import square_area, square_perimeter

__all__ = ["circle_area", "circle_perimeter",
           "triangle_area", "triangle_perimeter",
           "square_area", "square_perimeter"
           ]



from setuptools import setup

setup(name= "figures_07659443",
      version= "0.1",
      description= "With this program you can find areas and perimeters of 	different circles, triangles and squares",
      packages= ["figures_07659443"],
      author_email= "nevdokimov777@gmail.com",
      zip_safe=False)
